
<h1 align="center">
  <br>
  <a href="https://github.com/Zakovskiy/durakonline.py"><img src="https://github.com/Zakovskiy/durakonline.py/blob/main/icon.png?raw=true" width="500"></a>
  <br>
  Durak Online API on Python
  <br>
</h1>
<p align="center">
    <em><b>A customizable, fast and user-friendly framework for working with the Durak Online</b></em>
</p>
<p align="center">
  <a href="https://t.me/zakovskiy"><img src="https://kdramashindi.net/wp-content/uploads/2023/08/Telegram-1024x396.jpg"></a>
  <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/durakonline.py">
  <img alt="GitHub issues by-label" src="https://img.shields.io/github/issues/Zakovskiy/durakonline.py/bug">
  <img alt="PyPI" src="https://img.shields.io/pypi/v/durakonline.py?color=green&label=PyPI">
</p>

## Install
You can install the latest version using the command:

```shell
pip install durakonline.py
```

## Import and Auth
```python
from durakonline import durakonline

client = durakonline.Client()
client.authorization.signin_by_access_token("access token")
```
[How to get a token](https://github.com/Zakovskiy/durakonline.py/tree/main/docs)
<br>
[See more examples!](https://github.com/Zakovskiy/durakonline.py/tree/main/examples)

## Contributing

PR is supported! We are pleased to see your contribution to the development of the framework.\
Ask questions in the Issues block or in the [**Telegram**](https://t.me/zakovskiy)!
